@@ -11,6 +11,7 @@ from pyperf._cpu_utils import (format_cpu_list, parse_cpu_list,
                                get_isolated_cpus, set_cpu_affinity,
                                set_highest_priority)
 from pyperf._formatter import format_timedelta
+from pyperf._hooks import get_hook_names
 from pyperf._utils import (MS_WINDOWS, MAC_OS, abs_executable,
                            WritePipe, get_python_names,
                            merge_profile_stats)
@@ -69,23 +70,16 @@ class CLIError(Exception):
 class Runner:
     _created = set()
 
-    # Default parameters are chosen to have approximatively a run of 0.5 second
+    # Default parameters are chosen to have approximately a run of 0.5 second
     # and so a total duration of 5 seconds by default
     def __init__(self, values=None, processes=None,
                  loops=0, min_time=0.1, metadata=None,
                  show_name=True,
                  program_args=None, add_cmdline_args=None,
-                 _argparser=None):
-
-        # Reset the stats collection if running a --enable-pystats build
-        try:
-            sys._stats_off()
-            sys._stats_clear()
-        except AttributeError:
-            pass
+                 _argparser=None, warmups=1):
 
         # Watchdog: ensure that only once instance of Runner (or a Runner
-        # subclass) is created per process to prevent bad suprises
+        # subclass) is created per process to prevent bad surprises
         cls = self.__class__
         key = id(cls)
         if key in cls._created:
@@ -165,7 +159,7 @@ class Runner:
                             help='number of values per process (default: %s)'
                                  % values)
         parser.add_argument('-w', '--warmups',
-                            type=positive_or_nul,
+                            type=positive_or_nul, default=warmups,
                             help='number of skipped values per run used '
                                  'to warmup the benchmark')
         parser.add_argument('-l', '--loops',
@@ -189,6 +183,10 @@ class Runner:
                                  'value, used to calibrate the number of '
                                  'loops (default: %s)'
                             % format_timedelta(min_time))
+        parser.add_argument('--timeout',
+                            help='Specify a timeout in seconds for a single '
+                                 'benchmark execution (default: disabled)',
+                            type=strictly_positive)
         parser.add_argument('--worker', action='store_true',
                             help='Worker process, run the benchmark.')
         parser.add_argument('--worker-task', type=positive_or_nul, metavar='TASK_ID',
@@ -248,6 +246,13 @@ class Runner:
                             help='Collect profile data using cProfile '
                                  'and output to the given file.')
 
+        hook_names = list(get_hook_names())
+        parser.add_argument(
+            '--hook', action="append", choices=hook_names,
+            metavar=f"{', '.join(x for x in hook_names if not x.startswith('_'))}",
+            help='Use the given pyperf hooks'
+        )
+
         memory = parser.add_mutually_exclusive_group()
         memory.add_argument('--tracemalloc', action="store_true",
                             help='Trace memory allocations using tracemalloc')
@@ -732,6 +737,10 @@ class Runner:
         if self.args.profile:
             command.extend(["--profile", self.args.profile])
 
+        if self.args.hook:
+            for hook in self.args.hook:
+                command.extend(["--hook", hook])
+
         # Use lazy import to limit imports on 'import pyperf'
         from pyperf._command import BenchCommandTask
         task = BenchCommandTask(self, name, command)
