@@ -97,10 +97,7 @@ class TestRunner(unittest.TestCase):
 
         try:
             s = pstats.Stats(name)
-            if sys.version_info < (3, 9):
-                assert len(s.stats)
-            else:
-                assert len(s.get_stats_profile().func_profiles)
+            assert len(s.get_stats_profile().func_profiles)
         finally:
             if os.path.isfile(name):
                 os.unlink(name)
@@ -123,10 +120,7 @@ class TestRunner(unittest.TestCase):
         try:
             import pstats
             s = pstats.Stats(name)
-            if sys.version_info < (3, 9):
-                assert len(s.stats)
-            else:
-                assert len(s.get_stats_profile().func_profiles)
+            assert len(s.get_stats_profile().func_profiles)
         finally:
             if os.path.isfile(name):
                 os.unlink(name)
@@ -149,6 +143,33 @@ class TestRunner(unittest.TestCase):
         self.assertEqual(bench_json,
                          tests.benchmark_as_json(result.bench))
 
+    def test_pipe_with_timeout(self):
+        rpipe, wpipe = create_pipe()
+        with rpipe:
+            with wpipe:
+                arg = wpipe.to_subprocess()
+                # Don't close the file descriptor, it is closed by
+                # the Runner class
+                wpipe._fd = None
+
+                result = self.exec_runner('--pipe', str(arg),
+                                          '--worker', '-l1', '-w1')
+
+            # Mock the select to make the read pipeline not ready
+            with mock.patch('pyperf._utils.select.select',
+                            return_value=(False, False, False)):
+                with self.assertRaises(TimeoutError) as cm:
+                    rpipe.read_text(timeout=0.1)
+                self.assertEqual(str(cm.exception),
+                         'Timed out after 0.1 seconds')
+
+            # Mock the select to make the read pipeline ready
+            with mock.patch('pyperf._utils.select.select',
+                            return_value=(True, False, False)):
+                bench_json = rpipe.read_text(timeout=0.1)
+                self.assertEqual(bench_json.rstrip(),
+                                 tests.benchmark_as_json(result.bench).rstrip())
+
     def test_json_exists(self):
         with tempfile.NamedTemporaryFile('wb+') as tmp:
 
@@ -485,6 +506,18 @@ class TestRunner(unittest.TestCase):
         self.assertEqual(bench.get_metadata()['command'],
                          ' '.join(map(shell_quote, args)))
 
+    def test_hook_command(self):
+        args = [sys.executable, '-c', 'pass']
+
+        runner = self.create_runner('-l1 -w0 -n1 --worker --hook _test_hook'.split())
+        with tests.capture_stdout():
+            bench = runner.bench_command('bench', args)
+
+        self.assertEqual(bench.get_metadata()['command'],
+                         ' '.join(map(shell_quote, args)))
+        self.assertEqual(bench.get_metadata()["hooks"],
+                         "_test_hook")
+
     def test_single_instance(self):
         runner1 = self.create_runner([])   # noqa
         with self.assertRaises(RuntimeError):
